@@ -1,9 +1,9 @@
-__version__ = '1.0.3'
+__version__ = '1.0.4'
 
 from .commons.auth import Auth
 from .commons.compat import urlparse 
 from .commons.http import _post,_get
-from .commons.util import readfile,file_to_stream
+from .commons.util import readfile,file_to_stream,etag
 
 from .services.filemanager import BucketManager
 from .services.persistentfop import PersistentFop
